@@ -185,7 +185,8 @@ def construct_notification_command( title, body, urgency ):
         cmd += ["-h","string:bgcolor:#ff0000","-h","string:fgcolor:#ffffff"]
     if urgency == "low":
         cmd += ["-h","string:bgcolor:#000000","-h","string:fgcolor:#888888"]
-    cmd += [title,body]
+    cmd.append(title)
+    cmd.append(body)
     return cmd
 
 def init(args): # in_my_username, in_seconds_listen_channel):
